
//+SEQ,CopyRight,T=NOINCLUDE.

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// TPrimary                                                             //
// Is a small class in order to define the particles at the production  //
// vertex.                                                              //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#ifndef ROOT_TPrimary
#define ROOT_TPrimary

#ifndef ROOT_TNamed
//*KEEP,TNamed.
#include "TNamed.h"
//*KEND.
#endif
#ifndef ROOT_TAttLine
//*KEEP,TAttLine.
#include "TAttLine.h"
//*KEND.
#endif
#ifndef ROOT_X3DBuffer
//*KEEP,X3DBuffer,T=C.
#include "X3DBuffer.h"
//*KEND.
#endif

class TAttParticle;

class TPrimary : public TObject, public TAttLine {

 protected:
        Int_t         fPart;         //Particle id produced
        Int_t         fFirstMother;  //Index of the first mother particle
        Int_t         fSecondMother; //Index of the second mother particle(if any)
        Int_t         fGeneration;   //Generation flag: last gen. (0) or not (1) or ghost (2)
        Double_t      fPx;           //Momentum in x direction in GeV/c
        Double_t      fPy;           //Momentum in y direction in GeV/c
        Double_t      fPz;           //Momentum in z direction in GeV/c
        Double_t      fEtot;         //Total energy in GeV
        Double_t      fVx;           //Production vertex x position in user units
        Double_t      fVy;           //Production vertex y position in user units
        Double_t      fVz;           //Production vertex z position in user units
        Double_t      fTime;         //Time of particle production in user units
        Double_t      fTimeEnd;      //Time of particle destruction (always in the pp-cms!)
        TString       fType;         //Indicator of primary type

 public:
        TPrimary();
        TPrimary(Int_t part, Int_t first, Int_t second, Int_t gener,
                 Double_t px, Double_t py, Double_t pz,
                 Double_t etot, Double_t vx, Double_t vy, Double_t vz,
                 Double_t time, Double_t timend, Text_t *type = "");
        virtual ~TPrimary();
        virtual Int_t         DistancetoPrimitive(Int_t px, Int_t py);
        virtual void          ExecuteEvent(Int_t event, Int_t px, Int_t py);
        virtual const TAttParticle  *GetParticle() const;
        virtual const Text_t *GetName() const;
        virtual const Text_t *GetTitle() const;
        virtual Int_t         GetFirstMother() { return fFirstMother; }
        virtual Int_t         GetSecondMother() { return fSecondMother; }
        virtual Int_t         GetGeneration() { return fGeneration; }
        virtual Double_t      GetXMomentum() { return fPx; }
        virtual Double_t      GetYMomentum() { return fPy; }
        virtual Double_t      GetZMomentum() { return fPz; }
        virtual Double_t      GetTotalEnergy() { return fEtot; }
        virtual Double_t      GetXPosition() { return fVx; }
        virtual Double_t      GetYPosition() { return fVy; }
        virtual Double_t      GetZPosition() { return fVz; }
        virtual Double_t      GetTime() { return fTime; }
        virtual Double_t      GetTimeEnd() { return fTimeEnd; }
        virtual const Text_t  *GetType() const { return fType.Data(); }
        virtual Bool_t        Is3D() {return kTRUE;}
        virtual void          Paint(Option_t *option = "");
        virtual void          Print(Option_t *option = "");
        virtual void          Sizeof3D() const;

        ClassDef(TPrimary,1)  //TPrimary vertex particle information
};

#endif
